==> xlniuxdata-vipgame-1.0.62-20160520.074248-7-sources.jar: com/xunlei/niux/data/vipgame/dto/MobleGamesDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * 手游信息列表
 * Created by zy on 2016/3/15.
 */
public class MobleGamesDTO {

    private String seqId;
    private String gameId;
    private String gameNo;
    private String gameName;
    private String gameDesc;
    private String gameType;
    private String runStatus;
    private Long displayOrder;
    private String status;
    private String remark;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;
    private Integer clientType;
    private String simpleName;
    private Integer gameFeature;
    private Integer playLevel;
    private String picUrl;
    private String smallPicUrl;
    private Boolean isNew;
    private Boolean isHot;
    private String recommendIndex;

    //运营类型  0联运游戏1独代游戏
    private String runType;
    private String appSize;
    private Integer downloadNum;
    private String summary;
    private String packageName;
    private Boolean hasGift;
    private Boolean isFirstPublish;

    private String mobileSeqId;
    private Integer mobileGameClass;
    private Integer mobileGameType;
    private Integer mobileGameFeature;
    private Integer mobileGameTheme;
    private Integer mobileGameLable;

    public Integer getMobileGameClass() {
        return mobileGameClass;
    }

    public void setMobileGameClass(Integer mobileGameClass) {
        this.mobileGameClass = mobileGameClass;
    }

    public String getSeqId() {
        return seqId;
    }

    public void setSeqId(String seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGameNo() {
        return gameNo;
    }

    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public String getGameDesc() {
        return gameDesc;
    }

    public void setGameDesc(String gameDesc) {
        this.gameDesc = gameDesc;
    }

    public String getGameType() {
        return gameType;
    }

    public void setGameType(String gameType) {
        this.gameType = gameType;
    }

    public String getRunStatus() {
        return runStatus;
    }

    public void setRunStatus(String runStatus) {
        this.runStatus = runStatus;
    }


    public Long getDisplayOrder() {
        return displayOrder;
    }

    public void setDisplayOrder(Long displayOrder) {
        this.displayOrder = displayOrder;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }


    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }


    public String getSimpleName() {
        return simpleName;
    }

    public void setSimpleName(String simpleName) {
        this.simpleName = simpleName;
    }

    public Integer getGameFeature() {
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature) {
        this.gameFeature = gameFeature;
    }

    public Integer getPlayLevel() {
        return playLevel;
    }

    public void setPlayLevel(Integer playLevel) {
        this.playLevel = playLevel;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getSmallPicUrl() {
        return smallPicUrl;
    }

    public void setSmallPicUrl(String smallPicUrl) {
        this.smallPicUrl = smallPicUrl;
    }

    public Boolean getIsNew() {
        return isNew;
    }

    public void setIsNew(Boolean aNew) {
        isNew = aNew;
    }

    public Boolean getIsHot() {
        return isHot;
    }

    public void setIsHot(Boolean hot) {
        isHot = hot;
    }

    public String getRecommendIndex() {
        return recommendIndex;
    }

    public void setRecommendIndex(String recommendIndex) {
        this.recommendIndex = recommendIndex;
    }

    public String getRunType() {
        return runType;
    }

    public void setRunType(String runType) {
        this.runType = runType;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public Boolean getHasGift() {
        return hasGift;
    }

    public void setHasGift(Boolean hasGift) {
        this.hasGift = hasGift;
    }

    public String getMobileSeqId() {
        return mobileSeqId;
    }

    public void setMobileSeqId(String mobileSeqId) {
        this.mobileSeqId = mobileSeqId;
    }

    public Integer getMobileGameType() {
        return mobileGameType;
    }

    public void setMobileGameType(Integer mobileGameType) {
        this.mobileGameType = mobileGameType;
    }

    public Integer getMobileGameFeature() {
        return mobileGameFeature;
    }

    public void setMobileGameFeature(Integer mobileGameFeature) {
        this.mobileGameFeature = mobileGameFeature;
    }

    public Integer getMobileGameTheme() {
        return mobileGameTheme;
    }

    public void setMobileGameTheme(Integer mobileGameTheme) {
        this.mobileGameTheme = mobileGameTheme;
    }

    public Integer getMobileGameLable() {
        return mobileGameLable;
    }

    public void setMobileGameLable(Integer mobileGameLable) {
        this.mobileGameLable = mobileGameLable;
    }

    public Boolean getIsFirstPublish() {
        return isFirstPublish;
    }

    public void setIsFirstPublish(Boolean firstPublish) {
        isFirstPublish = firstPublish;
    }
}

==> xlniuxdata-vipgame-1.0.65-20181222.120647-126-sources.jar: com/xunlei/niux/data/vipgame/dto/MobleGamesDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

/**
 * 手游信息列表
 * Created by zy on 2016/3/15.
 */
public class MobleGamesDTO {

    private String seqId;
    private String gameId;
    private String gameNo;
    private String gameName;
    private String gameDesc;
    private String gameType;
    private String runStatus;
    private Long displayOrder;
    private String status;
    private String remark;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;
    private Integer clientType;
    private String simpleName;
    private Integer gameFeature;
    private Integer playLevel;
    private String picUrl;
    private String smallPicUrl;
    private Boolean isNew;
    private Boolean isHot;
    private String recommendIndex;

    //运营类型  0联运游戏1独代游戏
    private String runType;
    private String appSize;
    private Integer downloadNum;
    private String summary;
    private String packageName;
    private Boolean hasGift;
    private Boolean isFirstPublish;

    private String mobileSeqId;
    private Integer mobileGameClass;
    private Integer mobileGameType;
    private Integer mobileGameFeature;
    private Integer mobileGameTheme;
    private Integer mobileGameLable;
    private String videoUrl;
    private String videoDetailPicUrl;


    public Integer getMobileGameClass() {
        return mobileGameClass;
    }

    public void setMobileGameClass(Integer mobileGameClass) {
        this.mobileGameClass = mobileGameClass;
    }

    public String getSeqId() {
        return seqId;
    }

    public void setSeqId(String seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getGameNo() {
        return gameNo;
    }

    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public String getGameDesc() {
        return gameDesc;
    }

    public void setGameDesc(String gameDesc) {
        this.gameDesc = gameDesc;
    }

    public String getGameType() {
        return gameType;
    }

    public void setGameType(String gameType) {
        this.gameType = gameType;
    }

    public String getRunStatus() {
        return runStatus;
    }

    public void setRunStatus(String runStatus) {
        this.runStatus = runStatus;
    }


    public Long getDisplayOrder() {
        return displayOrder;
    }

    public void setDisplayOrder(Long displayOrder) {
        this.displayOrder = displayOrder;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }


    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }


    public String getSimpleName() {
        return simpleName;
    }

    public void setSimpleName(String simpleName) {
        this.simpleName = simpleName;
    }

    public Integer getGameFeature() {
        return gameFeature;
    }

    public void setGameFeature(Integer gameFeature) {
        this.gameFeature = gameFeature;
    }

    public Integer getPlayLevel() {
        return playLevel;
    }

    public void setPlayLevel(Integer playLevel) {
        this.playLevel = playLevel;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getSmallPicUrl() {
        return smallPicUrl;
    }

    public void setSmallPicUrl(String smallPicUrl) {
        this.smallPicUrl = smallPicUrl;
    }

    public Boolean getIsNew() {
        return isNew;
    }

    public void setIsNew(Boolean aNew) {
        isNew = aNew;
    }

    public Boolean getIsHot() {
        return isHot;
    }

    public void setIsHot(Boolean hot) {
        isHot = hot;
    }

    public String getRecommendIndex() {
        return recommendIndex;
    }

    public void setRecommendIndex(String recommendIndex) {
        this.recommendIndex = recommendIndex;
    }

    public String getRunType() {
        return runType;
    }

    public void setRunType(String runType) {
        this.runType = runType;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public Integer getDownloadNum() {
        return downloadNum;
    }

    public void setDownloadNum(Integer downloadNum) {
        this.downloadNum = downloadNum;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public Boolean getHasGift() {
        return hasGift;
    }

    public void setHasGift(Boolean hasGift) {
        this.hasGift = hasGift;
    }

    public String getMobileSeqId() {
        return mobileSeqId;
    }

    public void setMobileSeqId(String mobileSeqId) {
        this.mobileSeqId = mobileSeqId;
    }

    public Integer getMobileGameType() {
        return mobileGameType;
    }

    public void setMobileGameType(Integer mobileGameType) {
        this.mobileGameType = mobileGameType;
    }

    public Integer getMobileGameFeature() {
        return mobileGameFeature;
    }

    public void setMobileGameFeature(Integer mobileGameFeature) {
        this.mobileGameFeature = mobileGameFeature;
    }

    public Integer getMobileGameTheme() {
        return mobileGameTheme;
    }

    public void setMobileGameTheme(Integer mobileGameTheme) {
        this.mobileGameTheme = mobileGameTheme;
    }

    public Integer getMobileGameLable() {
        return mobileGameLable;
    }

    public void setMobileGameLable(Integer mobileGameLable) {
        this.mobileGameLable = mobileGameLable;
    }

    public Boolean getIsFirstPublish() {
        return isFirstPublish;
    }

    public void setIsFirstPublish(Boolean firstPublish) {
        isFirstPublish = firstPublish;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getVideoDetailPicUrl() {
        return videoDetailPicUrl;
    }

    public void setVideoDetailPicUrl(String videoDetailPicUrl) {
        this.videoDetailPicUrl = videoDetailPicUrl;
    }
}
